==> vim.js-1.1.2.tgz: package/README_CN.md <==
# 关于

`vim.js`是为网页端的`textarea`和`input`文本输入框打造的轻量级的简易vim书写扩展，
为喜欢用vim书写的用户在无需安装任何浏览器插件的情况下提供流畅高效的网页端书写体验。

[Demo here](http://toplan.github.io/vimjs/index.html)

**Note:**

* 该项目不是为了在网页端替代强大的IDEs，而是作为一项网页端书写(如写博客，写笔记等等)的增强功能。
* 该项目正在优化中，后续会有改进和新功能。
* 一般模式/视图模式中的指令需在英文输入法下输入。

![demo gif](http://7o503b.com1.z0.glb.clouddn.com/demo.gif)

# 使用

```html
<script src="/path/to/vim.js"></script>
<script type="text/javascript">
    vim.open({
        debug   : true,
        showMsg : function(msg){
            alert('vim.js say:' + msg);
        }
    });
</script>
```

# 开发和编译
```
//install
npm install vim.js

//watch
npm run dev

//build
npm run build

//build min js file
npm run build_min
```

# 支持的浏览器

* Chrome  v39
* Firefox  v34, v40
* Safari

**Note:**
其他浏览器的支持和兼容情况还有待测试

# 支持的功能

## 1. 一般模式
|  指令  |        说明             |
| ----- | ----------------------- |
| Esc   | 由编辑模式切换到一般模式    |
| u     | 复原前一个操作，支持多个文本域/输入框独立复原|
|          移动光标:               |
| h或左箭头键(←) | 光标向左移动一个字符   |
| j或下箭头键(↓) | 光标向下移动一个字符   |
| k或上箭头键(↑) | 光标向上移动一个字符   |
| l或右箭头键(→) | 光标向右移动一个字符   |
| 如果想进行多次移动，例如向下移动10行，可以使用"10j"，或"10↓"的组合键|
| 0或功能键[HOME]| 光标移动到当前行的第一个字符处 |
| $或功能键[End] | 光标移动到当前行的最后一个字符处 |
| G             | 光标移动到最后一行    |
| gg            | 光标移动到第一行      |
|          删除、复制与粘贴:        |
| x或功能键[Delete] | 向后删除一个字符 |
| nx或n[Delete] | 向后删除个字符 |
| yy           | 复制当前行      |
| nyy          | 向下复制n行     |
| dd           | 删除当前行      |
| ndd          | 向下删除n行      |
| p,P          | p向后粘贴，P向前粘贴|
| w或W         | 光标移动到下一个词语的第一个字符 |
| 支持nw 和 nW,向后移动`n`个词   |
| yw           | 复制以光标开始的第一个词 |
| 支持nyw, 向后复制`n`个词       |
| dw           | 删除以光标开始的第一个词 |
| 支持dyw, 向后复制`n`个词       |

## 2. 编辑模式
|  指令  |        说明             |
| ----- | ----------------------- |
| 进入插入或替换的编辑模式            |
| i     | 从目前光标所在出插入       |
| a     | 从目前光标所在的下一个字符处出插入|
| o,O   | o为在目前光标所在处的下一行处插入新的一行，O为在上一行插入新一行|
| r     | 替换光标所在的那一个字符    |

## 3. 视图模式
|  指令  |        说明             |
| ----- | ----------------------- |
| v,V   | 切换到视图模式，即多字符选择模式|
| y     | 复制选中的所有字符         |
| x,d   | 删除选中的所有字符         |

==> vim.js-1.1.4.tgz: package/README_CN.md <==
# 关于

`vim.js`是为网页端的`textarea`和`input`文本输入框打造的轻量级的简易vim书写扩展，
为喜欢用vim书写的用户在无需安装任何浏览器插件的情况下提供流畅高效的网页端书写体验。

[Demo here](http://toplan.github.io/vimjs/index.html)

**Note:**

* 该项目不是为了在网页端替代强大的IDEs，而是作为一项网页端书写(如写博客，写笔记等等)的增强功能。
* 该项目正在优化中，后续会有改进和新功能。
* 一般模式/视图模式中的指令需在英文输入法下输入。

![demo gif](http://7o503b.com1.z0.glb.clouddn.com/demo.gif)

# 使用

```html
<script src="/path/to/vim.js"></script>
<script type="text/javascript">
    vim.open({
        debug   : true,
        showMsg : function(msg){
            alert('vim.js say:' + msg);
        }
    });
</script>
```

# 开发和编译
```
//install
npm install vim.js

//watch
npm run dev

//build
npm run build

//build min js file
npm run build_min
```

# 支持的浏览器

* Chrome  v39
* Firefox  v34, v40
* Safari

**Note:**
其他浏览器的支持和兼容情况还有待测试

# 支持的功能

## 1. 一般模式
|  指令  |        说明             |
| ----- | ----------------------- |
| Esc   | 由编辑模式切换到一般模式    |
| u     | 复原前一个操作，支持多个文本域/输入框独立复原|
|          移动光标:               |
| h或左箭头键(←) | 光标向左移动一个字符   |
| j或下箭头键(↓) | 光标向下移动一个字符   |
| k或上箭头键(↑) | 光标向上移动一个字符   |
| l或右箭头键(→) | 光标向右移动一个字符   |
| 如果想进行多次移动，例如向下移动10行，可以使用"10j"，或"10↓"的组合键|
| 0或功能键[HOME]| 光标移动到当前行的第一个字符处 |
| $或功能键[End] | 光标移动到当前行的最后一个字符处 |
| G             | 光标移动到最后一行    |
| gg            | 光标移动到第一行      |
|          删除、复制与粘贴:        |
| x或功能键[Delete] | 向后删除一个字符 |
| nx或n[Delete] | 向后删除个字符 |
| yy           | 复制当前行      |
| nyy          | 向下复制n行     |
| dd           | 删除当前行      |
| ndd          | 向下删除n行      |
| p,P          | p向后粘贴，P向前粘贴|
| w或W         | 光标移动到下一个词语的第一个字符 |
| 支持nw 和 nW,向后移动`n`个词   |
| yw 或 yW     | 复制以光标开始的第一个词 |
| 支持nyw 和 nyW, 向后复制`n`个词       |
| dw 或 dW     | 删除以光标开始的第一个词 |
| 支持dyw 和 dyW, 向后复制`n`个词       |

## 2. 编辑模式
|  指令  |        说明             |
| ----- | ----------------------- |
| 进入插入或替换的编辑模式            |
| i     | 从目前光标所在出插入       |
| a     | 从目前光标所在的下一个字符处出插入|
| o,O   | o为在目前光标所在处的下一行处插入新的一行，O为在上一行插入新一行|
| r     | 替换光标所在的那一个字符    |

## 3. 视图模式
|  指令  |        说明             |
| ----- | ----------------------- |
| v,V   | 切换到视图模式，即多字符选择模式|
| y     | 复制选中的所有字符         |
| x,d   | 删除选中的所有字符         |
